@@ -32,15 +32,16 @@ from .. import errors as brz_errors
 from .. import trace, urlutils, version_info
 from ..commands import plugin_cmds
 from ..controldir import ControlDirFormat, Prober, format_registry
-from ..controldir import \
-    network_format_registry as controldir_network_format_registry
-from ..transport import (register_lazy_transport, register_transport_proto,
-                         transport_server_registry)
+from ..controldir import network_format_registry as controldir_network_format_registry
+from ..transport import (
+    register_lazy_transport,
+    register_transport_proto,
+    transport_server_registry,
+)
 
 if getattr(sys, "frozen", None):
     # allow import additional libs from ./_lib for bzr.exe only
-    sys.path.append(os.path.normpath(
-        os.path.join(os.path.dirname(__file__), '_lib')))
+    sys.path.append(os.path.normpath(os.path.join(os.path.dirname(__file__), "_lib")))
 
 
 def import_dulwich():
@@ -48,14 +49,15 @@ def import_dulwich():
         from dulwich import __version__ as dulwich_version
     except ModuleNotFoundError:
         raise brz_errors.DependencyNotPresent(
-            "dulwich",
-            "bzr-git: Please install dulwich, https://www.dulwich.io/")
+            "dulwich", "bzr-git: Please install dulwich, https://www.dulwich.io/"
+        )
     else:
         if dulwich_version < dulwich_minimum_version:
             raise brz_errors.DependencyNotPresent(
                 "dulwich",
-                "bzr-git: Dulwich is too old; at least %d.%d.%d is required" %
-                dulwich_minimum_version)
+                "bzr-git: Dulwich is too old; at least %d.%d.%d is required"
+                % dulwich_minimum_version,
+            )
 
 
 _versions_checked = False
@@ -70,24 +72,32 @@ def lazy_check_versions():
 
 
 format_registry.register_lazy(
-    'git', __name__ + ".dir", "LocalGitControlDirFormat",
-    help='GIT repository.', native=False, experimental=False)
+    "git",
+    __name__ + ".dir",
+    "LocalGitControlDirFormat",
+    help="GIT repository.",
+    native=False,
+    experimental=False,
+)
 
 format_registry.register_lazy(
-    'git-bare', __name__ + ".dir", "BareLocalGitControlDirFormat",
-    help='Bare GIT repository (no working tree).', native=False,
-    experimental=False)
+    "git-bare",
+    __name__ + ".dir",
+    "BareLocalGitControlDirFormat",
+    help="Bare GIT repository (no working tree).",
+    native=False,
+    experimental=False,
+)
 
 from ..revisionspec import RevisionSpec_dwim, revspec_registry
 
-revspec_registry.register_lazy("git:", __name__ + ".revspec",
-                               "RevisionSpec_git")
+revspec_registry.register_lazy("git:", __name__ + ".revspec", "RevisionSpec_git")
 RevisionSpec_dwim.append_possible_lazy_revspec(
-    __name__ + ".revspec", "RevisionSpec_git")
+    __name__ + ".revspec", "RevisionSpec_git"
+)
 
 
 class LocalGitProber(Prober):
-
     @classmethod
     def priority(klass, transport):
         return 10
@@ -97,25 +107,26 @@ class LocalGitProber(Prober):
             external_url = transport.external_url()
         except brz_errors.InProcessTransport:
             raise brz_errors.NotBranchError(path=transport.base)
-        if (external_url.startswith("http:") or
-                external_url.startswith("https:")):
+        if external_url.startswith("http:") or external_url.startswith("https:"):
             # Already handled by RemoteGitProber
             raise brz_errors.NotBranchError(path=transport.base)
         if urlutils.split(transport.base)[1] == ".git":
             raise brz_errors.NotBranchError(path=transport.base)
-        if not transport.has_any(['objects', '.git/objects', '.git']):
+        if not transport.has_any(["objects", ".git/objects", ".git"]):
             raise brz_errors.NotBranchError(path=transport.base)
         lazy_check_versions()
         from .dir import BareLocalGitControlDirFormat, LocalGitControlDirFormat
-        if transport.has_any(['.git/objects', '.git']):
+
+        if transport.has_any([".git/objects", ".git"]):
             return LocalGitControlDirFormat()
-        if transport.has('info') and transport.has('objects'):
+        if transport.has("info") and transport.has("objects"):
             return BareLocalGitControlDirFormat()
         raise brz_errors.NotBranchError(path=transport.base)
 
     @classmethod
     def known_formats(cls):
         from .dir import BareLocalGitControlDirFormat, LocalGitControlDirFormat
+
         return [BareLocalGitControlDirFormat(), LocalGitControlDirFormat()]
 
 
@@ -125,18 +136,16 @@ def user_agent_for_github():
 
 
 def is_github_url(url):
-    (scheme, user, password, host, port,
-     path) = urlutils.parse_url(url)
+    (scheme, user, password, host, port, path) = urlutils.parse_url(url)
     return host in ("github.com", "gopkg.in")
 
 
 class RemoteGitProber(Prober):
-
     @classmethod
     def priority(klass, transport):
         # This is a surprisingly good heuristic to determine whether this
         # prober is more likely to succeed than the Bazaar one.
-        if 'git' in transport.base:
+        if "git" in transport.base:
             return -15
         return -10
 
@@ -151,29 +160,33 @@ class RemoteGitProber(Prober):
         url.password = url.quoted_password = None
         host = url.host
         url = urlutils.join(str(url), "info/refs") + "?service=git-upload-pack"
-        headers = {"Content-Type": "application/x-git-upload-pack-request",
-                   "Accept": "application/x-git-upload-pack-result",
-                   }
+        headers = {
+            "Content-Type": "application/x-git-upload-pack-request",
+            "Accept": "application/x-git-upload-pack-result",
+        }
         if is_github_url(url):
             # GitHub requires we lie.
             # https://github.com/dulwich/dulwich/issues/562
             headers["User-Agent"] = user_agent_for_github()
-        resp = transport.request('GET', url, headers=headers)
+        resp = transport.request("GET", url, headers=headers)
         if resp.status in (404, 405):
             raise brz_errors.NotBranchError(transport.base)
-        elif resp.status == 400 and resp.reason == 'no such method: info':
+        elif resp.status == 400 and resp.reason == "no such method: info":
             # hgweb :(
             raise brz_errors.NotBranchError(transport.base)
         elif resp.status != 200:
             raise brz_errors.UnexpectedHttpStatus(
-                url, resp.status, headers=resp.getheaders())
+                url, resp.status, headers=resp.getheaders()
+            )
 
         ct = resp.getheader("Content-Type")
         if ct and ct.startswith("application/x-git"):
             from .remote import RemoteGitControlDirFormat
+
             return RemoteGitControlDirFormat()
         elif not ct:
             from .dir import BareLocalGitControlDirFormat
+
             ret = BareLocalGitControlDirFormat()
             ret._refs_text = resp.read()
             return ret
@@ -185,16 +198,17 @@ class RemoteGitProber(Prober):
         except brz_errors.InProcessTransport:
             raise brz_errors.NotBranchError(path=transport.base)
 
-        if (external_url.startswith("http:") or
-                external_url.startswith("https:")):
+        if external_url.startswith("http:") or external_url.startswith("https:"):
             return self.probe_http_transport(transport)
 
-        if (not external_url.startswith("git://") and
-                not external_url.startswith("git+")):
+        if not external_url.startswith("git://") and not external_url.startswith(
+            "git+"
+        ):
             raise brz_errors.NotBranchError(transport.base)
 
         # little ugly, but works
         from .remote import GitSmartTransport, RemoteGitControlDirFormat
+
         if isinstance(transport, GitSmartTransport):
             return RemoteGitControlDirFormat()
         raise brz_errors.NotBranchError(path=transport.base)
@@ -202,32 +216,33 @@ class RemoteGitProber(Prober):
     @classmethod
     def known_formats(cls):
         from .remote import RemoteGitControlDirFormat
+
         return [RemoteGitControlDirFormat()]
 
 
 ControlDirFormat.register_prober(LocalGitProber)
 ControlDirFormat.register_prober(RemoteGitProber)
 
+register_transport_proto("git://", help="Access using the Git smart server protocol.")
 register_transport_proto(
-    'git://', help="Access using the Git smart server protocol.")
-register_transport_proto(
-    'git+ssh://',
-    help="Access using the Git smart server protocol over SSH.")
+    "git+ssh://", help="Access using the Git smart server protocol over SSH."
+)
 
-register_lazy_transport("git://", __name__ + '.remote',
-                        'TCPGitSmartTransport')
-register_lazy_transport("git+ssh://", __name__ + '.remote',
-                        'SSHGitSmartTransport')
+register_lazy_transport("git://", __name__ + ".remote", "TCPGitSmartTransport")
+register_lazy_transport("git+ssh://", __name__ + ".remote", "SSHGitSmartTransport")
 
 
 plugin_cmds.register_lazy("cmd_git_import", [], __name__ + ".commands")
-plugin_cmds.register_lazy("cmd_git_object", ["git-objects", "git-cat"],
-                          __name__ + ".commands")
+plugin_cmds.register_lazy(
+    "cmd_git_object", ["git-objects", "git-cat"], __name__ + ".commands"
+)
 plugin_cmds.register_lazy("cmd_git_refs", [], __name__ + ".commands")
 plugin_cmds.register_lazy("cmd_git_apply", [], __name__ + ".commands")
-plugin_cmds.register_lazy("cmd_git_push_pristine_tar_deltas",
-                          ['git-push-pristine-tar', 'git-push-pristine'],
-                          __name__ + ".commands")
+plugin_cmds.register_lazy(
+    "cmd_git_push_pristine_tar_deltas",
+    ["git-push-pristine-tar", "git-push-pristine"],
+    __name__ + ".commands",
+)
 
 
 def extract_git_foreign_revid(rev):
@@ -235,11 +250,12 @@ def extract_git_foreign_revid(rev):
         foreign_revid = rev.foreign_revid
     except AttributeError:
         from .mapping import mapping_registry
-        foreign_revid, mapping = \
-            mapping_registry.parse_revision_id(rev.revision_id)
+
+        foreign_revid, mapping = mapping_registry.parse_revision_id(rev.revision_id)
         return foreign_revid
     else:
         from .mapping import foreign_vcs_git
+
         if rev.mapping.vcs == foreign_vcs_git:
             return foreign_revid
         else:
@@ -259,107 +275,141 @@ from ..hooks import install_lazy_named_hook
 
 install_lazy_named_hook(
     "breezy.version_info_formats.format_rio",
-    "RioVersionInfoBuilder.hooks", "revision", update_stanza,
-    "git commits")
+    "RioVersionInfoBuilder.hooks",
+    "revision",
+    update_stanza,
+    "git commits",
+)
 
 
 def rewrite_instead_of(location, purpose):
-    from dulwich.config import StackedConfig, apply_instead_of
+    from dulwich.config import StackedConfig, iter_instead_of
 
     config = StackedConfig.default()
 
-    return apply_instead_of(config, location, push=(purpose == "push"))
+    push = purpose != "read"
+
+    longest_needle = ""
+    updated_url = location
+    for needle, replacement in iter_instead_of(config, push):
+        if not location.startswith(needle):
+            continue
+        if len(longest_needle) < len(needle):
+            longest_needle = needle
+            if longest_needle == "lp:":
+                # Leave the lp: prefix to the launchpad plugin, if loaded
+                import breezy.plugins
+
+                if hasattr(breezy.plugins, "launchpad"):
+                    trace.warning(
+                        "Ignoring insteadOf lp: in git config, because the Launchpad plugin is loaded."
+                    )
+                    continue
+            updated_url = replacement + location[len(needle) :]
+    return updated_url
 
 
 from ..location import hooks as location_hooks
 
 location_hooks.install_named_hook(
-    "rewrite_location", rewrite_instead_of,
-    "apply Git insteadOf / pushInsteadOf")
+    "rewrite_location", rewrite_instead_of, "apply Git insteadOf / pushInsteadOf"
+)
 
 transport_server_registry.register_lazy(
-    'git', __name__ + '.server', 'serve_git',
-    'Git Smart server protocol over TCP. (default port: 9418)')
+    "git",
+    __name__ + ".server",
+    "serve_git",
+    "Git Smart server protocol over TCP. (default port: 9418)",
+)
 
 transport_server_registry.register_lazy(
-    'git-receive-pack', __name__ + '.server',
-    'serve_git_receive_pack',
-    help='Git Smart server receive pack command. (inetd mode only)')
+    "git-receive-pack",
+    __name__ + ".server",
+    "serve_git_receive_pack",
+    help="Git Smart server receive pack command. (inetd mode only)",
+)
 transport_server_registry.register_lazy(
-    'git-upload-pack', __name__ + 'git.server',
-    'serve_git_upload_pack',
-    help='Git Smart server upload pack command. (inetd mode only)')
+    "git-upload-pack",
+    __name__ + "git.server",
+    "serve_git_upload_pack",
+    help="Git Smart server upload pack command. (inetd mode only)",
+)
 
 from ..repository import format_registry as repository_format_registry
-from ..repository import \
-    network_format_registry as repository_network_format_registry
+from ..repository import network_format_registry as repository_network_format_registry
 
 repository_network_format_registry.register_lazy(
-    b'git', __name__ + '.repository', 'GitRepositoryFormat')
+    b"git", __name__ + ".repository", "GitRepositoryFormat"
+)
 
-register_extra_lazy_repository_format = getattr(repository_format_registry,
-                                                "register_extra_lazy")
-register_extra_lazy_repository_format(__name__ + '.repository',
-                                      'GitRepositoryFormat')
+register_extra_lazy_repository_format = getattr(
+    repository_format_registry, "register_extra_lazy"
+)
+register_extra_lazy_repository_format(__name__ + ".repository", "GitRepositoryFormat")
 
 from ..branch import network_format_registry as branch_network_format_registry
 
 branch_network_format_registry.register_lazy(
-    b'git', __name__ + '.branch', 'LocalGitBranchFormat')
+    b"git", __name__ + ".branch", "LocalGitBranchFormat"
+)
 
 
 from ..branch import format_registry as branch_format_registry
 
 branch_format_registry.register_extra_lazy(
-    __name__ + '.branch',
-    'LocalGitBranchFormat',
-    )
+    __name__ + ".branch",
+    "LocalGitBranchFormat",
+)
 branch_format_registry.register_extra_lazy(
-    __name__ + '.remote',
-    'RemoteGitBranchFormat',
-    )
+    __name__ + ".remote",
+    "RemoteGitBranchFormat",
+)
 
 
 from ..workingtree import format_registry as workingtree_format_registry
 
 workingtree_format_registry.register_extra_lazy(
-    __name__ + '.workingtree',
-    'GitWorkingTreeFormat',
-    )
+    __name__ + ".workingtree",
+    "GitWorkingTreeFormat",
+)
 
 controldir_network_format_registry.register_lazy(
-    b'git', __name__ + ".dir", "GitControlDirFormat")
+    b"git", __name__ + ".dir", "GitControlDirFormat"
+)
 
 
 from ..diff import format_registry as diff_format_registry
 
 diff_format_registry.register_lazy(
-    'git', __name__ + '.send',
-    'GitDiffTree', 'Git am-style diff format')
+    "git", __name__ + ".send", "GitDiffTree", "Git am-style diff format"
+)
 
 from ..send import format_registry as send_format_registry
 
-send_format_registry.register_lazy('git', __name__ + '.send',
-                                   'send_git', 'Git am-style diff format')
+send_format_registry.register_lazy(
+    "git", __name__ + ".send", "send_git", "Git am-style diff format"
+)
 
 from ..directory_service import directories
 
-directories.register_lazy('github:', __name__ + '.directory',
-                          'GitHubDirectory',
-                          'GitHub directory.')
-directories.register_lazy('git@github.com:', __name__ + '.directory',
-                          'GitHubDirectory',
-                          'GitHub directory.')
+directories.register_lazy(
+    "github:", __name__ + ".directory", "GitHubDirectory", "GitHub directory."
+)
+directories.register_lazy(
+    "git@github.com:", __name__ + ".directory", "GitHubDirectory", "GitHub directory."
+)
 
 from ..help_topics import topic_registry
 
 topic_registry.register_lazy(
-    'git', __name__ + '.help', 'help_git', 'Using Bazaar with Git')
+    "git", __name__ + ".help", "help_git", "Using Bazaar with Git"
+)
 
 from ..foreign import foreign_vcs_registry
 
 foreign_vcs_registry.register_lazy(
-    "git", __name__ + ".mapping", "foreign_vcs_git", "Stupid content tracker")
+    "git", __name__ + ".mapping", "foreign_vcs_git", "Stupid content tracker"
+)
 
 
 def update_git_cache(repository, revid):
@@ -373,10 +423,10 @@ def update_git_cache(repository, revid):
         lazy_check_versions()
     except brz_errors.DependencyNotPresent as e:
         # dulwich is probably missing. silently ignore
-        trace.mutter("not updating git map for %r: %s",
-                     repository, e)
+        trace.mutter("not updating git map for %r: %s", repository, e)
 
     from .object_store import BazaarObjectStore
+
     store = BazaarObjectStore(repository)
     with store.lock_write():
         try:
@@ -398,8 +448,9 @@ def update_git_cache(repository, revid):
                 store._cache.idmap.commit_write_group()
 
 
-def post_commit_update_cache(local_branch, master_branch, old_revno, old_revid,
-                             new_revno, new_revid):
+def post_commit_update_cache(
+    local_branch, master_branch, old_revno, old_revid, new_revno, new_revid
+):
     if local_branch is not None:
         update_git_cache(local_branch.repository, new_revid)
     update_git_cache(master_branch.repository, new_revid)
@@ -408,33 +459,47 @@ def post_commit_update_cache(local_branch, master_branch, old_revno, old_revid,
 def loggerhead_git_hook(branch_app, environ):
     branch = branch_app.branch
     config_stack = branch.get_config_stack()
-    if not config_stack.get('git.http'):
+    if not config_stack.get("git.http"):
         return None
     from .server import git_http_hook
-    return git_http_hook(branch, environ['REQUEST_METHOD'],
-                         environ['PATH_INFO'])
+
+    return git_http_hook(branch, environ["REQUEST_METHOD"], environ["PATH_INFO"])
 
 
-install_lazy_named_hook("breezy.branch",
-                        "Branch.hooks", "post_commit",
-                        post_commit_update_cache, "git cache")
-install_lazy_named_hook("breezy.plugins.loggerhead.apps.branch",
-                        "BranchWSGIApp.hooks", "controller",
-                        loggerhead_git_hook, "git support")
+install_lazy_named_hook(
+    "breezy.branch",
+    "Branch.hooks",
+    "post_commit",
+    post_commit_update_cache,
+    "git cache",
+)
+install_lazy_named_hook(
+    "breezy.plugins.loggerhead.apps.branch",
+    "BranchWSGIApp.hooks",
+    "controller",
+    loggerhead_git_hook,
+    "git support",
+)
 
 
 from ..config import Option, bool_from_store, option_registry
 
 option_registry.register(
-    Option('git.http',
-           default=None, from_unicode=bool_from_store, invalid='warning',
-           help='''\
+    Option(
+        "git.http",
+        default=None,
+        from_unicode=bool_from_store,
+        invalid="warning",
+        help="""\
 Allow fetching of Git packs over HTTP.
 
 This enables support for fetching Git packs over HTTP in Loggerhead.
-'''))
+""",
+    )
+)
 
 
 def test_suite():
     from . import tests
+
     return tests.test_suite()
