@@ -17,18 +17,14 @@
 
 from operator import itemgetter
 
-from ... import errors, osutils, transport
-from ...trace import show_error, note
-
 from breezy import controldir
-from .helpers import (
-    best_format_for_objects_in_a_repository,
-    single_plural,
-    )
+
+from ... import errors, osutils, transport
+from ...trace import note, show_error
+from .helpers import best_format_for_objects_in_a_repository, single_plural
 
 
 class BranchUpdater:
-
     def __init__(self, repo, branch, cache_mgr, heads_by_ref, last_ref, tags):
         """Create an object responsible for updating branches.
 
@@ -42,8 +38,7 @@ class BranchUpdater:
         self.heads_by_ref = heads_by_ref
         self.last_ref = last_ref
         self.tags = tags
-        self._branch_format = \
-            best_format_for_objects_in_a_repository(repo)
+        self._branch_format = best_format_for_objects_in_a_repository(repo)
 
     def update(self):
         """Update the Bazaar branches and tips matching the heads.
@@ -87,8 +82,7 @@ class BranchUpdater:
         # already put the 'trunk' first, do it now.
         git_to_bzr_map = {}
         for ref_name in ref_names:
-            git_to_bzr_map[ref_name] = self.cache_mgr.branch_mapper.git_to_bzr(
-                ref_name)
+            git_to_bzr_map[ref_name] = self.cache_mgr.branch_mapper.git_to_bzr(ref_name)
         if ref_names and self.branch is None:
             trunk = self.select_trunk(ref_names)
             git_bzr_items = [(trunk, git_to_bzr_map[trunk])]
@@ -106,6 +100,7 @@ class BranchUpdater:
         def dir_sister_branch(name):
             # Using the Bazaar name, get a sister directory to the branch
             return osutils.pathjoin(self.branch.base, "..", name)
+
         if self.branch is not None:
             dir_policy = dir_sister_branch
         else:
@@ -113,8 +108,8 @@ class BranchUpdater:
 
         # Create/track missing branches
         can_create_branches = (
-            self.repo.is_shared() or
-            self.repo.controldir._format.colocated_branches)
+            self.repo.is_shared() or self.repo.controldir._format.colocated_branches
+        )
         for ref_name, name in git_bzr_items:
             tip = self.heads_by_ref[ref_name][0]
             if can_create_branches:
@@ -123,8 +118,7 @@ class BranchUpdater:
                     branch_tips.append((br, tip))
                     continue
                 except errors.BzrError as ex:
-                    show_error("ERROR: failed to create branch %s: %s",
-                               name, ex)
+                    show_error("ERROR: failed to create branch %s: %s", name, ex)
             lost_head = self.cache_mgr.lookup_committish(tip)
             lost_info = (name, lost_head)
             lost_heads.append(lost_info)
@@ -132,7 +126,7 @@ class BranchUpdater:
 
     def select_trunk(self, ref_names):
         """Given a set of ref names, choose one as the trunk."""
-        for candidate in ['refs/heads/master']:
+        for candidate in ["refs/heads/master"]:
             if candidate in ref_names:
                 return candidate
         # Use the last reference in the import stream
@@ -150,7 +144,8 @@ class BranchUpdater:
                 return controldir.ControlDir.create_branch_convenience(
                     location,
                     format=self._branch_format,
-                    possible_transports=[to_transport])
+                    possible_transports=[to_transport],
+                )
         else:
             try:
                 return self.repo.controldir.open_branch(name)
@@ -175,8 +170,9 @@ class BranchUpdater:
         my_tags = {}
         if self.tags:
             graph = self.repo.get_graph()
-            ancestry = [r for (r, ps) in graph.iter_ancestry(
-                [last_rev_id]) if ps is not None]
+            ancestry = [
+                r for (r, ps) in graph.iter_ancestry([last_rev_id]) if ps is not None
+            ]
             for tag, rev in self.tags.items():
                 if rev in ancestry:
                     my_tags[tag] = rev
@@ -185,7 +181,12 @@ class BranchUpdater:
                 changed = True
         if changed:
             tagno = len(my_tags)
-            note("\t branch %s now has %d %s and %d %s", br.nick,
-                 revno, single_plural(revno, "revision", "revisions"),
-                 tagno, single_plural(tagno, "tag", "tags"))
+            note(
+                "\t branch %s now has %d %s and %d %s",
+                br.nick,
+                revno,
+                single_plural(revno, "revision", "revisions"),
+                tagno,
+                single_plural(tagno, "tag", "tags"),
+            )
         return changed
