@@ -16,11 +16,13 @@
 
 __docformat__ = "google"
 
-from typing import List, Type, TYPE_CHECKING, Optional, Iterable
+from typing import TYPE_CHECKING, Iterable, List, Optional, Type
 
 from .lazy_import import lazy_import
 
-lazy_import(globals(), """
+lazy_import(
+    globals(),
+    """
 import time
 
 from breezy import (
@@ -28,22 +30,23 @@ from breezy import (
     osutils,
     )
 from breezy.i18n import gettext
-""")
+""",
+)
 
-from . import controldir, debug, errors, graph, registry, revision as _mod_revision, ui
+from . import controldir, debug, errors, graph, registry
+from . import revision as _mod_revision
+from . import ui
 from .decorators import only_raises
 from .inter import InterObject
 from .lock import LogicalLockResult, _RelockDebugMixin
 from .revisiontree import RevisionTree
-from .trace import (log_exception_quietly, mutter, mutter_callsite, note,
-                    warning)
+from .trace import log_exception_quietly, mutter, mutter_callsite, note, warning
 
 # Old formats display a warning, but only once
 _deprecation_warning_done = False
 
 
 class IsInWriteGroupError(errors.InternalBzrError):
-
     _fmt = "May not refresh_data of repo %(repo)s while in a write group."
 
     def __init__(self, repo):
@@ -51,7 +54,6 @@ class IsInWriteGroupError(errors.InternalBzrError):
 
 
 class CannotSetRevisionId(errors.BzrError):
-
     _fmt = "Repository format does not support setting revision ids."
 
 
@@ -81,9 +83,18 @@ class CommitBuilder:
     # being committed to
     updates_branch = False
 
-    def __init__(self, repository, parents, config_stack, timestamp=None,
-                 timezone=None, committer=None, revprops=None,
-                 revision_id=None, lossy=False):
+    def __init__(
+        self,
+        repository,
+        parents,
+        config_stack,
+        timestamp=None,
+        timezone=None,
+        committer=None,
+        revprops=None,
+        revision_id=None,
+        lossy=False,
+    ):
         """Initiate a CommitBuilder.
 
         Args:
@@ -101,7 +112,7 @@ class CommitBuilder:
         self._lossy = lossy
 
         if committer is None:
-            self._committer = self._config_stack.get('email')
+            self._committer = self._config_stack.get("email")
         elif not isinstance(committer, str):
             self._committer = committer.decode()  # throw if non-ascii
         else:
@@ -140,19 +151,20 @@ class CommitBuilder:
     def _validate_unicode_text(self, text, context):
         """Verify things like commit messages don't have bogus characters."""
         # TODO(jelmer): Make this repository-format specific
-        if '\r' in text:
-            raise ValueError('Invalid value for {}: {!r}'.format(context, text))
+        if "\r" in text:
+            raise ValueError("Invalid value for {}: {!r}".format(context, text))
 
     def _validate_revprops(self, revprops):
         for key, value in revprops.items():
             # We know that the XML serializers do not round trip '\r'
             # correctly, so refuse to accept them
             if not isinstance(value, str):
-                raise ValueError('revision property (%s) is not a valid'
-                                 ' (unicode) string: %r' % (key, value))
+                raise ValueError(
+                    "revision property (%s) is not a valid"
+                    " (unicode) string: %r" % (key, value)
+                )
             # TODO(jelmer): Make this repository-format specific
-            self._validate_unicode_text(value,
-                                        'revision property ({})'.format(key))
+            self._validate_unicode_text(value, "revision property ({})".format(key))
 
     def commit(self, message):
         """Make the actual commit.
@@ -162,8 +174,7 @@ class CommitBuilder:
         raise NotImplementedError(self.commit)
 
     def abort(self):
-        """Abort the commit that is being built.
-        """
+        """Abort the commit that is being built."""
         raise NotImplementedError(self.abort)
 
     def revision_tree(self) -> "RevisionTree":
@@ -238,8 +249,9 @@ class RepositoryWriteLockResult(LogicalLockResult):
         self.repository_token = repository_token
 
     def __repr__(self):
-        return "RepositoryWriteLockResult({}, {})".format(self.repository_token,
-                                                      self.unlock)
+        return "RepositoryWriteLockResult({}, {})".format(
+            self.repository_token, self.unlock
+        )
 
 
 class WriteGroup:
@@ -295,21 +307,24 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             # has an unlock or relock occured ?
             if suppress_errors:
                 mutter(
-                    '(suppressed) mismatched lock context and write group. %r, %r',
-                    self._write_group, self.get_transaction())
+                    "(suppressed) mismatched lock context and write group. %r, %r",
+                    self._write_group,
+                    self.get_transaction(),
+                )
                 return
             raise errors.BzrError(
-                'mismatched lock context and write group. %r, %r' %
-                (self._write_group, self.get_transaction()))
+                "mismatched lock context and write group. %r, %r"
+                % (self._write_group, self.get_transaction())
+            )
         try:
             self._abort_write_group()
         except Exception as exc:
             self._write_group = None
             if not suppress_errors:
                 raise
-            mutter('abort_write_group failed')
+            mutter("abort_write_group failed")
             log_exception_quietly()
-            note(gettext('brz: ERROR (ignored): %s'), exc)
+            note(gettext("brz: ERROR (ignored): %s"), exc)
         self._write_group = None
 
     def _abort_write_group(self):
@@ -351,7 +366,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         revisions that might be present.  There is no direct replacement
         method.
         """
-        if 'evil' in debug.debug_flags:
+        if "evil" in debug.debug_flags:
             mutter_callsite(2, "all_revision_ids is linear with history.")
         return self._all_revision_ids()
 
@@ -407,13 +422,11 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
 
     def __repr__(self):
         if self._fallback_repositories:
-            return '{}({!r}, fallback_repositories={!r})'.format(
-                self.__class__.__name__,
-                self.base,
-                self._fallback_repositories)
+            return "{}({!r}, fallback_repositories={!r})".format(
+                self.__class__.__name__, self.base, self._fallback_repositories
+            )
         else:
-            return '{}({!r})'.format(self.__class__.__name__,
-                               self.base)
+            return "{}({!r})".format(self.__class__.__name__, self.base)
 
     def _has_same_fallbacks(self, other_repo):
         """Returns true if the repositories have the same fallbacks."""
@@ -435,7 +448,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         """
         if self.__class__ is not other.__class__:
             return False
-        return (self.control_url == other.control_url)
+        return self.control_url == other.control_url
 
     def is_in_write_group(self):
         """Return True if there is an open write group.
@@ -449,7 +462,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
 
     def is_write_locked(self):
         """Return True if this object is write locked."""
-        return self.is_locked() and self.control_files._lock_mode == 'w'
+        return self.is_locked() and self.control_files._lock_mode == "w"
 
     def lock_write(self, token=None):
         """Lock this repository for writing.
@@ -483,7 +496,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         token = self.control_files.lock_write(token=token)
         if not locked:
             self._warn_if_deprecated()
-            self._note_lock('w')
+            self._note_lock("w")
             for repo in self._fallback_repositories:
                 # Writes don't affect fallback repos
                 repo.lock_read()
@@ -500,7 +513,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         self.control_files.lock_read()
         if not locked:
             self._warn_if_deprecated()
-            self._note_lock('r')
+            self._note_lock("r")
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
@@ -545,13 +558,16 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         with self.lock_read():
             result = {}
             if revid and committers:
-                result['committers'] = 0
+                result["committers"] = 0
             if revid and revid != _mod_revision.NULL_REVISION:
                 graph = self.get_graph()
                 if committers:
                     all_committers = set()
-                revisions = [r for (r, p) in graph.iter_ancestry([revid])
-                             if r != _mod_revision.NULL_REVISION]
+                revisions = [
+                    r
+                    for (r, p) in graph.iter_ancestry([revid])
+                    if r != _mod_revision.NULL_REVISION
+                ]
                 last_revision = None
                 if not committers:
                     # ignore the revisions in the middle - just grab first and last
@@ -563,11 +579,9 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
                         all_committers.add(revision.committer)
                 first_revision = revision
                 if committers:
-                    result['committers'] = len(all_committers)
-                result['firstrev'] = (first_revision.timestamp,
-                                      first_revision.timezone)
-                result['latestrev'] = (last_revision.timestamp,
-                                       last_revision.timezone)
+                    result["committers"] = len(all_committers)
+                result["firstrev"] = (first_revision.timestamp, first_revision.timezone)
+                result["latestrev"] = (last_revision.timestamp, last_revision.timezone)
             return result
 
     def find_branches(self, using=False):
@@ -583,7 +597,6 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             return
 
         class Evaluator:
-
             def __init__(self):
                 self.first_call = True
 
@@ -602,15 +615,21 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
                 return True, value
 
         for branches, repository in controldir.ControlDir.find_controldirs(
-                self.user_transport, evaluate=Evaluator()):
+            self.user_transport, evaluate=Evaluator()
+        ):
             if branches is not None:
                 yield from branches
             if not using and repository is not None:
                 yield from repository.find_branches()
 
-    def search_missing_revision_ids(self, other,
-                                    find_ghosts=True, revision_ids=None, if_present_ids=None,
-                                    limit=None):
+    def search_missing_revision_ids(
+        self,
+        other,
+        find_ghosts=True,
+        revision_ids=None,
+        if_present_ids=None,
+        limit=None,
+    ):
         """Return the revision ids that other has that this does not.
 
         These are returned in topological order.
@@ -619,8 +638,11 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         """
         with self.lock_read():
             return InterRepository.get(other, self).search_missing_revision_ids(
-                find_ghosts=find_ghosts, revision_ids=revision_ids,
-                if_present_ids=if_present_ids, limit=limit)
+                find_ghosts=find_ghosts,
+                revision_ids=revision_ids,
+                if_present_ids=if_present_ids,
+                limit=limit,
+            )
 
     @staticmethod
     def open(base):
@@ -649,9 +671,10 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         """
         if self._write_group is not self.get_transaction():
             # has an unlock or relock occured ?
-            raise errors.BzrError('mismatched lock context %r and '
-                                  'write group %r.' %
-                                  (self.get_transaction(), self._write_group))
+            raise errors.BzrError(
+                "mismatched lock context %r and "
+                "write group %r." % (self.get_transaction(), self._write_group)
+            )
         result = self._commit_write_group()
         self._write_group = None
         return result
@@ -694,7 +717,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         if not self.is_write_locked():
             raise errors.NotWriteLocked(self)
         if self._write_group:
-            raise errors.BzrError('already in a write group')
+            raise errors.BzrError("already in a write group")
         self._resume_write_group(tokens)
         # so we can detect unlock/relock - the write group is now entered.
         self._write_group = self.get_transaction()
@@ -721,26 +744,33 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         Returns: A FetchResult object
         """
         if self.is_in_write_group():
-            raise errors.InternalBzrError(
-                "May not fetch while in a write group.")
+            raise errors.InternalBzrError("May not fetch while in a write group.")
         # fast path same-url fetch operations
         # TODO: lift out to somewhere common with RemoteRepository
         # <https://bugs.launchpad.net/bzr/+bug/401646>
-        if (self.has_same_location(source)
-                and self._has_same_fallbacks(source)):
+        if self.has_same_location(source) and self._has_same_fallbacks(source):
             # check that last_revision is in 'from' and then return a
             # no-operation.
-            if (revision_id is not None and
-                    not _mod_revision.is_null(revision_id)):
+            if revision_id is not None and not _mod_revision.is_null(revision_id):
                 self.get_revision(revision_id)
             return 0, []
         inter = InterRepository.get(source, self)
         return inter.fetch(
-            revision_id=revision_id, find_ghosts=find_ghosts, lossy=lossy)
+            revision_id=revision_id, find_ghosts=find_ghosts, lossy=lossy
+        )
 
-    def get_commit_builder(self, branch, parents, config_stack, timestamp=None,
-                           timezone=None, committer=None, revprops=None,
-                           revision_id=None, lossy=False):
+    def get_commit_builder(
+        self,
+        branch,
+        parents,
+        config_stack,
+        timestamp=None,
+        timezone=None,
+        committer=None,
+        revprops=None,
+        revision_id=None,
+        lossy=False,
+    ):
         """Obtain a CommitBuilder for this repository.
 
         Args:
@@ -759,13 +789,13 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
 
     @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
-        if (self.control_files._lock_count == 1 and
-                self.control_files._lock_mode == 'w'):
+        if self.control_files._lock_count == 1 and self.control_files._lock_mode == "w":
             if self._write_group is not None:
                 self.abort_write_group()
                 self.control_files.unlock()
                 raise errors.BzrError(
-                    'Must end write groups before releasing write locks.')
+                    "Must end write groups before releasing write locks."
+                )
         self.control_files.unlock()
         if self.control_files._lock_count == 0:
             for repo in self._fallback_repositories:
@@ -782,8 +812,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         with self.lock_read():
             # TODO: deprecate after 0.16; cloning this with all its settings is
             # probably not very useful -- mbp 20070423
-            dest_repo = self._create_sprouting_repo(
-                controldir, shared=self.is_shared())
+            dest_repo = self._create_sprouting_repo(controldir, shared=self.is_shared())
             self.copy_content_into(dest_repo, revision_id)
             return dest_repo
 
@@ -805,7 +834,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         if not self.is_write_locked():
             raise errors.NotWriteLocked(self)
         if self._write_group:
-            raise errors.BzrError('already in a write group')
+            raise errors.BzrError("already in a write group")
         self._start_write_group()
         # so we can detect unlock/relock - the write group is now entered.
         self._write_group = self.get_transaction()
@@ -828,16 +857,14 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             return dest_repo
 
     def _create_sprouting_repo(self, a_controldir, shared):
-        if not isinstance(
-                a_controldir._format, self.controldir._format.__class__):
+        if not isinstance(a_controldir._format, self.controldir._format.__class__):
             # use target default format.
             dest_repo = a_controldir.create_repository()
         else:
             # Most control formats need the repository to be specifically
             # created, but on some old all-in-one formats it's not needed
             try:
-                dest_repo = self._format.initialize(
-                    a_controldir, shared=shared)
+                dest_repo = self._format.initialize(a_controldir, shared=shared)
             except errors.UninitializableFormat:
                 dest_repo = a_controldir.open_repository()
         return dest_repo
@@ -930,9 +957,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             required_trees.add(revision.revision_id)
             required_trees.update(revision.parent_ids[:1])
 
-        trees = {
-            t.get_revision_id(): t
-            for t in self.revision_trees(required_trees)}
+        trees = {t.get_revision_id(): t for t in self.revision_trees(required_trees)}
 
         # Calculate the deltas
         for revision in revisions:
@@ -944,9 +969,10 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             yield intertree.compare(specific_files=specific_files)
             if specific_files is not None:
                 specific_files = [
-                    p for p in intertree.find_source_paths(
-                        specific_files).values()
-                    if p is not None]
+                    p
+                    for p in intertree.find_source_paths(specific_files).values()
+                    if p is not None
+                ]
 
     def store_revision_signature(self, gpg_strategy, plaintext, revision_id):
         raise NotImplementedError(self.store_revision_signature)
@@ -991,8 +1017,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
         if distance_from_known < 0:
             raise errors.RevnoOutOfBounds(revno, (0, known_revno))
         try:
-            _iter_for_revno(
-                self, partial_history, stop_index=distance_from_known)
+            _iter_for_revno(self, partial_history, stop_index=distance_from_known)
         except errors.RevisionNotPresent as err:
             if err.revision_id == known_revid:
                 # The start revision (known_revid) wasn't found.
@@ -1007,7 +1032,7 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             earliest_revno = known_revno - len(partial_history) + 1
             return (False, (earliest_revno, partial_history[-1]))
         if len(partial_history) - 1 > distance_from_known:
-            raise AssertionError('_iter_for_revno returned too much history')
+            raise AssertionError("_iter_for_revno returned too much history")
         return (True, partial_history[-1])
 
     def is_shared(self):
@@ -1087,15 +1112,15 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             if revision_id == _mod_revision.NULL_REVISION:
                 result[revision_id] = ()
             elif revision_id is None:
-                raise ValueError('get_parent_map(None) is not valid')
+                raise ValueError("get_parent_map(None) is not valid")
             else:
                 query_keys.append((revision_id,))
         vf = self.revisions.without_fallbacks()
-        for (revision_id,), parent_keys in (
-                vf.get_parent_map(query_keys).items()):
+        for (revision_id,), parent_keys in vf.get_parent_map(query_keys).items():
             if parent_keys:
-                result[revision_id] = tuple([parent_revid
-                                             for (parent_revid,) in parent_keys])
+                result[revision_id] = tuple(
+                    [parent_revid for (parent_revid,) in parent_keys]
+                )
             else:
                 result[revision_id] = (_mod_revision.NULL_REVISION,)
         return result
@@ -1103,17 +1128,17 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
     def _make_parents_provider(self):
         if not self._format.supports_external_lookups:
             return self
-        return graph.StackedParentsProvider(_LazyListJoin(
-            [self._make_parents_provider_unstacked()],
-            self._fallback_repositories))
+        return graph.StackedParentsProvider(
+            _LazyListJoin(
+                [self._make_parents_provider_unstacked()], self._fallback_repositories
+            )
+        )
 
     def _make_parents_provider_unstacked(self):
-        return graph.CallableToParentsProviderAdapter(
-            self._get_parent_map_no_fallbacks)
+        return graph.CallableToParentsProviderAdapter(self._get_parent_map_no_fallbacks)
 
     def get_known_graph_ancestry(self, revision_ids):
-        """Return the known graph for a set of revision ids and their ancestors.
-        """
+        """Return the known graph for a set of revision ids and their ancestors."""
         raise NotImplementedError(self.get_known_graph_ancestry)
 
     def get_file_graph(self):
@@ -1123,10 +1148,12 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
     def get_graph(self, other_repository=None):
         """Return the graph walker for this repository format"""
         parents_provider = self._make_parents_provider()
-        if (other_repository is not None and
-                not self.has_same_location(other_repository)):
+        if other_repository is not None and not self.has_same_location(
+            other_repository
+        ):
             parents_provider = graph.StackedParentsProvider(
-                [parents_provider, other_repository._make_parents_provider()])
+                [parents_provider, other_repository._make_parents_provider()]
+            )
         return graph.Graph(parents_provider)
 
     def set_make_working_trees(self, new_value):
@@ -1197,8 +1224,11 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
           check_repo: If False do not check the repository contents, just
             calculate the data callback_refs requires and call them back.
         """
-        return self._check(revision_ids=revision_ids, callback_refs=callback_refs,
-                           check_repo=check_repo)
+        return self._check(
+            revision_ids=revision_ids,
+            callback_refs=callback_refs,
+            check_repo=check_repo,
+        )
 
     def _check(self, revision_ids=None, callback_refs=None, check_repo=True):
         raise NotImplementedError(self.check)
@@ -1214,11 +1244,13 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
                 conf = config.GlobalStack()
             else:
                 conf = branch.get_config_stack()
-            if 'format_deprecation' in conf.get('suppress_warnings'):
+            if "format_deprecation" in conf.get("suppress_warnings"):
                 return
-            warning("Format %s for %s is deprecated -"
-                    " please use 'brz upgrade' to get better performance"
-                    % (self._format, self.controldir.transport.base))
+            warning(
+                "Format %s for %s is deprecated -"
+                " please use 'brz upgrade' to get better performance"
+                % (self._format, self.controldir.transport.base)
+            )
         finally:
             _deprecation_warning_done = True
 
@@ -1232,12 +1264,12 @@ class Repository(controldir.ControlComponent, _RelockDebugMixin):
             # weaves require ascii revision ids.
             if isinstance(revision_id, str):
                 try:
-                    revision_id.encode('ascii')
+                    revision_id.encode("ascii")
                 except UnicodeEncodeError:
                     raise errors.NonAsciiRevisionId(method, self)
             else:
                 try:
-                    revision_id.decode('ascii')
+                    revision_id.decode("ascii")
                 except UnicodeDecodeError:
                     raise errors.NonAsciiRevisionId(method, self)
 
@@ -1247,7 +1279,7 @@ class RepositoryFormatRegistry(controldir.ControlComponentFormatRegistry):
 
     def get_default(self):
         """Return the current default format."""
-        return controldir.format_registry.make_controldir('default').repository_format
+        return controldir.format_registry.make_controldir("default").repository_format
 
 
 network_format_registry = registry.FormatRegistry["RepositoryFormat"]()
@@ -1270,6 +1302,7 @@ can be called to obtain one.
 #####################################################################
 # Repository Formats
 
+
 class RepositoryFormat(controldir.ControlComponentFormat):
     """A repository format.
 
@@ -1419,13 +1452,14 @@ class RepositoryFormat(controldir.ControlComponentFormat):
     def check_conversion_target(self, target_format):
         if self.rich_root_data and not target_format.rich_root_data:
             raise errors.BadConversionTarget(
-                'Does not support rich root data.', target_format,
-                from_format=self)
-        if (self.supports_tree_reference
-                and not getattr(target_format, 'supports_tree_reference', False)):
+                "Does not support rich root data.", target_format, from_format=self
+            )
+        if self.supports_tree_reference and not getattr(
+            target_format, "supports_tree_reference", False
+        ):
             raise errors.BadConversionTarget(
-                'Does not support nested trees', target_format,
-                from_format=self)
+                "Does not support nested trees", target_format, from_format=self
+            )
 
     def open(self, controldir, _found=False):
         """Return an instance of this format for a controldir.
@@ -1436,7 +1470,8 @@ class RepositoryFormat(controldir.ControlComponentFormat):
 
     def _run_post_repo_init_hooks(self, repository, controldir, shared):
         from .controldir import ControlDir, RepoInitHookParams
-        hooks = ControlDir.hooks['post_repo_init']
+
+        hooks = ControlDir.hooks["post_repo_init"]
         if not hooks:
             return
         params = RepoInitHookParams(repository, self, controldir, shared)
@@ -1504,7 +1539,9 @@ class InterRepository(InterObject[Repository]):
     _optimisers = []
     """The available optimised InterRepository types."""
 
-    def copy_content(self, revision_id: Optional[_mod_revision.RevisionID] = None) -> None:
+    def copy_content(
+        self, revision_id: Optional[_mod_revision.RevisionID] = None
+    ) -> None:
         """Make a complete copy of the content in self into destination.
 
         This is a destructive operation! Do not use it on existing
@@ -1516,13 +1553,17 @@ class InterRepository(InterObject[Repository]):
         """
         with self.lock_write():
             try:
-                self.target.set_make_working_trees(
-                    self.source.make_working_trees())
+                self.target.set_make_working_trees(self.source.make_working_trees())
             except (NotImplementedError, errors.RepositoryUpgradeRequired):
                 pass
             self.target.fetch(self.source, revision_id=revision_id)
 
-    def fetch(self, revision_id: Optional[_mod_revision.RevisionID] = None, find_ghosts: bool = False, lossy: bool = False) -> FetchResult:
+    def fetch(
+        self,
+        revision_id: Optional[_mod_revision.RevisionID] = None,
+        find_ghosts: bool = False,
+        lossy: bool = False,
+    ) -> FetchResult:
         """Fetch the content required to construct revision_id.
 
         The content is copied from self.source to self.target.
@@ -1535,9 +1576,12 @@ class InterRepository(InterObject[Repository]):
         raise NotImplementedError(self.fetch)
 
     def search_missing_revision_ids(
-            self, find_ghosts: bool = True, revision_ids: Optional[Iterable[_mod_revision.RevisionID]] = None,
-            if_present_ids: Optional[Iterable[_mod_revision.RevisionID]] = None,
-            limit: Optional[int] = None) -> AbstractSearchResult:
+        self,
+        find_ghosts: bool = True,
+        revision_ids: Optional[Iterable[_mod_revision.RevisionID]] = None,
+        if_present_ids: Optional[Iterable[_mod_revision.RevisionID]] = None,
+        limit: Optional[int] = None,
+    ) -> AbstractSearchResult:
         """Return the revision ids that source has that target does not.
 
         Args:
@@ -1571,19 +1615,22 @@ class InterRepository(InterObject[Repository]):
 
     @staticmethod
     def _assert_same_model(source, target):
-        """Raise an exception if two repositories do not use the same model.
-        """
+        """Raise an exception if two repositories do not use the same model."""
         if source.supports_rich_root() != target.supports_rich_root():
-            raise errors.IncompatibleRepositories(source, target,
-                                                  "different rich-root support")
-        if not hasattr(source, '_serializer') or not hasattr(target, '_serializer'):
+            raise errors.IncompatibleRepositories(
+                source, target, "different rich-root support"
+            )
+        if not hasattr(source, "_serializer") or not hasattr(target, "_serializer"):
             if source != target:
-                raise errors.IncompatibleRepositories(source, target, "different formats")
+                raise errors.IncompatibleRepositories(
+                    source, target, "different formats"
+                )
             return
 
         if source._serializer != target._serializer:
-            raise errors.IncompatibleRepositories(source, target,
-                                                  "different serializers")
+            raise errors.IncompatibleRepositories(
+                source, target, "different serializers"
+            )
 
 
 class CopyConverter:
@@ -1614,23 +1661,23 @@ class CopyConverter:
             # trigger an assertion if not such
             repo._format.get_format_string()
             self.repo_dir = repo.controldir
-            pb.update(gettext('Moving repository to repository.backup'))
-            self.repo_dir.transport.move('repository', 'repository.backup')
-            backup_transport = self.repo_dir.transport.clone(
-                'repository.backup')
+            pb.update(gettext("Moving repository to repository.backup"))
+            self.repo_dir.transport.move("repository", "repository.backup")
+            backup_transport = self.repo_dir.transport.clone("repository.backup")
             repo._format.check_conversion_target(self.target_format)
-            self.source_repo = repo._format.open(self.repo_dir,
-                                                 _found=True,
-                                                 _override_transport=backup_transport)
-            pb.update(gettext('Creating new repository'))
-            converted = self.target_format.initialize(self.repo_dir,
-                                                      self.source_repo.is_shared())
+            self.source_repo = repo._format.open(
+                self.repo_dir, _found=True, _override_transport=backup_transport
+            )
+            pb.update(gettext("Creating new repository"))
+            converted = self.target_format.initialize(
+                self.repo_dir, self.source_repo.is_shared()
+            )
             with converted.lock_write():
-                pb.update(gettext('Copying content'))
+                pb.update(gettext("Copying content"))
                 self.source_repo.copy_content_into(converted)
-            pb.update(gettext('Deleting old repository content'))
-            self.repo_dir.transport.delete_tree('repository.backup')
-            ui.ui_factory.note(gettext('repository converted'))
+            pb.update(gettext("Deleting old repository content"))
+            self.repo_dir.transport.delete_tree("repository.backup")
+            ui.ui_factory.note(gettext("repository converted"))
 
 
 def _strip_NULL_ghosts(revision_graph):
@@ -1639,13 +1686,13 @@ def _strip_NULL_ghosts(revision_graph):
     if _mod_revision.NULL_REVISION in revision_graph:
         del revision_graph[_mod_revision.NULL_REVISION]
     for key, parents in revision_graph.items():
-        revision_graph[key] = tuple(parent for parent in parents if parent
-                                    in revision_graph)
+        revision_graph[key] = tuple(
+            parent for parent in parents if parent in revision_graph
+        )
     return revision_graph
 
 
-def _iter_for_revno(repo, partial_history_cache, stop_index=None,
-                    stop_revision=None):
+def _iter_for_revno(repo, partial_history_cache, stop_index=None, stop_revision=None):
     """Extend the partial history to include a given index
 
     If a stop_index is supplied, stop when that index has been reached.
@@ -1661,14 +1708,14 @@ def _iter_for_revno(repo, partial_history_cache, stop_index=None,
     """
     start_revision = partial_history_cache[-1]
     graph = repo.get_graph()
-    iterator = graph.iter_lefthand_ancestry(start_revision,
-                                            (_mod_revision.NULL_REVISION,))
+    iterator = graph.iter_lefthand_ancestry(
+        start_revision, (_mod_revision.NULL_REVISION,)
+    )
     try:
         # skip the last revision in the list
         next(iterator)
         while True:
-            if (stop_index is not None and
-                    len(partial_history_cache) > stop_index):
+            if stop_index is not None and len(partial_history_cache) > stop_index:
                 break
             if partial_history_cache[-1] == stop_revision:
                 break
@@ -1704,5 +1751,6 @@ class _LazyListJoin:
         return iter(full_list)
 
     def __repr__(self):
-        return "{}.{}({})".format(self.__module__, self.__class__.__name__,
-                              self.list_parts)
+        return "{}.{}({})".format(
+            self.__module__, self.__class__.__name__, self.list_parts
+        )
